@@ -1,11 +1,11 @@
 package AnyEvent::Consul;
-$AnyEvent::Consul::VERSION = '0.004';
+$AnyEvent::Consul::VERSION = '0.005';
 # ABSTRACT: Make async calls to Consul via AnyEvent
 
 use warnings;
 use strict;
 
-use Consul;
+use Consul 0.016;
 use AnyEvent::HTTP qw(http_request);
 use Hash::MultiValue;
 use Carp qw(croak);
@@ -35,12 +35,6 @@ sub new {
             );
             return;
         },
-        error_cb => sub {
-            my ($msg, $resp) = @_;
-            my $on_error = $resp->request->args->{on_error};
-            return $on_error->($msg) if ref $on_error eq 'CODE';
-            croak $msg;
-        },
     );
 }
 
@@ -59,6 +53,8 @@ sub status  { shift->new(@_)->status  }
 
 =encoding UTF-8
 
+=for markdown [![Build Status](https://secure.travis-ci.org/robn/AnyEvent-Consul.png)](http://travis-ci.org/robn/AnyEvent-Consul)
+
 =head1 NAME
 
 AnyEvent::Consul - Make async calls to Consul via AnyEvent
